var tabs = require("sdk/tabs");
var pageMod = require("sdk/page-mod");
var pageWorker = require("sdk/page-worker");
var panel = require("sdk/panel");
var self = require("sdk/self");
var data = require("sdk/self").data;
var preferences = require("sdk/simple-prefs").prefs;
var preferencesService = require("sdk/preferences/service");
var notifications = require("sdk/notifications");
var Request = require("sdk/request").Request;
var windows = require("sdk/windows");
var { viewFor } = require("sdk/view/core");

var { ToggleButton } = require("sdk/ui/button/toggle");

var _ = require("sdk/l10n").get;

var notifications = [];

function loadAddonConfig(reload = false) {
	var addonConfig = Request({
	  url: 'resource://info-at-ytdownloader-dot-info/data/configuration.json',
	  onComplete: function (response) {
		var config = JSON.parse(response.text);  
		
		configTimestamp = Date.now();
		
		if (config.notifications) {
			notifications = config.notifications;
		}
		
		preferences.disableSupport = false;
	  }
	});
	addonConfig.get();
}

var youtubePanel = panel.Panel({
	contentURL: data.url('youtube-panel.html'),
	contentScriptFile: data.url('youtube-panel-script.js'),
	contentScriptWhen: 'end',
	onHide: youtubeHandleHide
});

var tempLink = '';
var tempFormat = '';
youtubePanel.port.on('doDownload', function(format) {
	tempLink = tabs.activeTab.url;
	tempFormat = format;
	youtubePanel.hide();
	if (preferences.openNewTab) {
		tabs.open('http://convert2mp3.net/index.php?p=home');
	} else {
		tabs.activeTab.url = 'http://convert2mp3.net/index.php?p=home';
	}
});

var youtubeButton = ToggleButton({
	id: "youtube-download-button",
	label: "YouTube Download",
	icon: {
		"32": "./youtube-download-inactive.png",
	},
	disabled: true,
	onChange: youtubeHandleChange
});

function youtubeHandleChange(state) {
	if (state.checked) {
		youtubePanel.show({
		  position: youtubeButton,
		  width: 250,
		  height: 150
		});
	}
}

function youtubeHandleHide() {
  youtubeButton.state('window', {checked: false});
}

tabs.on('activate', function (tab) {
	if (tab.url.indexOf('youtube.com/watch?v=') != -1) {
		youtubeButton.disabled = false;
		youtubeButton.icon = {"32": "./youtube-download-active.png"};
		youtubePanel.port.emit('setVideoTitle', tab.title.replace(' - YouTube', ''));
	} else {
		youtubeButton.disabled = true;
		youtubeButton.icon = {"32": "./youtube-download-inactive.png"};
	}
});

pageMod.PageMod({
	include: "*.youtube.com",
	attachTo: ["top"],
	contentScriptFile: data.url("check-script.js"),
	contentScriptWhen: 'ready',
	onAttach: function(worker) {
		worker.port.on('setVideoData', function(title) {
			if (title != '') {
				youtubeButton.disabled = false;
				youtubeButton.icon = {"32": "./youtube-download-active.png"};
				youtubePanel.port.emit('setVideoTitle', title);
			} else {
				youtubeButton.disabled = true;
				youtubeButton.icon = {"32": "./youtube-download-inactive.png"};
			}
		});
	}
});

pageMod.PageMod({
	include: "*.convert2mp3.net",
	attachTo: ["top"],
	contentScriptFile: [data.url("jquery-1.12.1.min.js"), data.url("convert2mp3-script.js")],
	contentScriptWhen: 'ready',
	onAttach: function(worker) {
		worker.port.emit("setTempData", tempLink, tempFormat);
		tempLink = '';
		tempFormat = '';
	}
});

pageMod.PageMod({
	include: "*.youtube.com",
	attachTo: ["top"],
	contentScriptFile: [data.url("jquery-1.12.1.min.js"), data.url("notification-script.js")],
	contentScriptWhen: 'end',
	onAttach: function(worker) {
		worker.port.on('getNotifications', function() {
			if (!preferences.disableNotifications) {
				for (var i = 0; i < notifications.length; i++) {
					worker.port.emit("applyNotifications", notifications[i].type, notifications[i].selector, notifications[i].content);
				}
				
				worker.port.emit("applyActions", '');
			}
		});
		
		worker.port.on('showDownloadPanel', function(panelTop, panelLeft) {
			youtubePanel.show({
			  position: {top: panelTop, left: panelLeft},
			  width: 250,
			  height: 150
			});
		});
		
		worker.port.on('doDownload', function(format) {
			tempLink = tabs.activeTab.url;
			tempFormat = format;
			if (preferences.openNewTab) {
				tabs.open('http://convert2mp3.net/index.php?p=home');
			} else {
				tabs.activeTab.url = 'http://convert2mp3.net/index.php?p=home';
			}
		});
	}
});



exports.main = function (options, callbacks) {
	loadAddonConfig();
	
	if (options.loadReason == 'install') {
		tabs.open('http://www.ytdownloader.info/api/pages/install.html');
	} else if (options.loadReason == 'upgrade') {
		tabs.open('http://www.ytdownloader.info/api/pages/upgrade.html');
	}
};

exports.onUnload = function(reason) {
	if (reason == 'uninstall' || reason == 'disable') {
		tabs.open('http://www.ytdownloader.info/api/pages/uninstall.html');
	}
}
